#!/bin/sh
#
# Copyright (c) Members of the EGEE Collaboration. 2004-2010.
# See http://www.eu-egee.org/partners/ for details on the
# copyright holders.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
# either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

GRID_SECURITY=/etc/grid-security
HOST_JKS=${GRID_SECURITY}/hostcert.ks
CA_JKS=${GRID_SECURITY}/certificates.ts

TMPFILE=$(mktemp) || exit 1

for i in ${GRID_SECURITY}/certificates/*.0 ; do
    j=$(echo $i | sed -e 's_.*/__g;s/\.0$//')
    cat $i | grep -A 100 "BEGIN CERTIFICATE-----" > $TMPFILE
    keytool -importcert -keystore $CA_JKS.$$ -noprompt \
            -storepass changeit -alias $j -file $TMPFILE \
        || echo -e "\n\tFAILED: $i\n"
done

mv -f $CA_JKS.$$ $CA_JKS

OLD_UMASK=`umask`
umask 0077

openssl pkcs12 -export \
    -in $GRID_SECURITY/hostcert.pem -inkey $GRID_SECURITY/hostkey.pem \
    -passout pass:changeit -out $TMPFILE

keytool -importkeystore -srckeystore $TMPFILE -srcstorepass changeit \
    -destkeystore $HOST_JKS.$$ -srcstoretype pkcs12 \
    -deststoretype jks -deststorepass changeit

rm -f $TMPFILE

mv -f $HOST_JKS.$$ $HOST_JKS

[ -n "$OLD_UMASK" ] && umask "$OLD_UMASK"

